@@ -1,19 +1,23 @@
 import re
 import tempfile
+import time
 from pathlib import Path
-from typing import List, Tuple
+from typing import Iterator, List, Tuple
 
+from robot.libdocpkg.model import KeywordDoc, LibraryDoc
 from robot.libraries.BuiltIn import BuiltIn
 from robot.parsing import get_model
-from robot.running import TestSuite
+from robot.running import TestSuite, UserLibrary
 from robot.variables.search import is_variable
 
-from .robotlib import ImportedLibraryDocBuilder, get_libs
+from .robotlib import ImportedLibraryDocBuilder, ImportedResourceDocBuilder, get_libs
 
 KEYWORD_SEP = re.compile("  +|\t")
 
 _lib_keywords_cache = {}
+_resource_keywords_cache = {}
 temp_resources = []
+last_keyword_exec_time = 0
 
 
 def parse_keyword(command) -> Tuple[List[str], str, List[str]]:
@@ -33,45 +37,44 @@ def parse_keyword(command) -> Tuple[List[str], str, List[str]]:
     return variables, keyword, args
 
 
-def get_lib_keywords(library):
+def get_lib_keywords(library) -> List[KeywordDoc]:
     """Get keywords of imported library."""
-    if library.name in _lib_keywords_cache:
-        return _lib_keywords_cache[library.name]
-
-    lib = ImportedLibraryDocBuilder().build(library)
-    keywords = []
-    for keyword in lib.keywords:
-        keywords.append(
-            {
-                "name": keyword.name,
-                "lib": library.name,
-                "doc": keyword.doc,
-                "summary": keyword.doc.split("\n")[0],
-            }
-        )
-
-    _lib_keywords_cache[library.name] = keywords
-    return keywords
+    if library.name not in _lib_keywords_cache:
+        if isinstance(library, UserLibrary):
+            _lib_keywords_cache[library.name]: LibraryDoc = ImportedResourceDocBuilder().build(
+                library
+            )
+        else:
+            _lib_keywords_cache[library.name]: LibraryDoc = ImportedLibraryDocBuilder().build(
+                library
+            )
+    return _lib_keywords_cache[library.name].keywords
 
 
-def get_keywords():
+def get_keywords() -> Iterator[KeywordDoc]:
     """Get all keywords of libraries."""
     for lib in get_libs():
         yield from get_lib_keywords(lib)
 
 
-def find_keyword(keyword_name):
+def find_keyword(keyword_name) -> List[KeywordDoc]:
     keyword_name = keyword_name.lower()
     return [
         keyword
         for lib in get_libs()
         for keyword in get_lib_keywords(lib)
-        if keyword["name"].lower() == keyword_name
+        if normalize_kw(keyword.name) == normalize_kw(keyword_name)
     ]
 
 
+def normalize_kw(keyword_name):
+    return keyword_name.lower().replace("_", "").replace(" ", "")
+
+
 def run_command(builtin, command: str) -> List[Tuple[str, str]]:
     """Run a command in robotframewrk environment."""
+    global last_keyword_exec_time
+    last_keyword_exec_time = 0
     if not command:
         return []
     if is_variable(command):
@@ -80,15 +83,18 @@ def run_command(builtin, command: str) -> List[Tuple[str, str]]:
     if command.startswith("***"):
         _import_resource_from_string(command)
         return []
-
     test = get_test_body_from_string(command)
     if len(test.body) > 1:
+        start = time.monotonic()
         for kw in test.body:
             kw.run(ctx)
+        last_keyword_exec_time = time.monotonic() - start
         return_val = None
     else:
         kw = test.body[0]
+        start = time.monotonic()
         return_val = kw.run(ctx)
+        last_keyword_exec_time = time.monotonic() - start
     assign = set(_get_assignments(test))
     if not assign and return_val is not None:
         return [("<", repr(return_val))]
@@ -103,6 +109,13 @@ def run_command(builtin, command: str) -> List[Tuple[str, str]]:
         return []
 
 
+def get_rprompt_text():
+    """Get text for bottom toolbar."""
+    if last_keyword_exec_time == 0:
+        return
+    return [("class:pygments.comment", f"# ΔT: {last_keyword_exec_time:.3f}s")]
+
+
 def get_test_body_from_string(command):
     if "\n" in command:
         command = "\n  ".join(command.split("\n"))
