@@ -7,9 +7,9 @@ from robot import run_cli
 TEST_SUITE = b"""*** Settings ***
 Library  RobotDebug
 
-** test case **
+*** Test Cases ***
 Robot Framework Debug REPL
-    debug
+    Debug
 """
 
 
